@@ -6,7 +6,8 @@ Revs:
 import corr, numpy,sys,os,time,logging
 
 def exit_fail():
-    print 'FAILURE DETECTED. Log entries:\n',lh.printMessages()
+    print 'FAILURE DETECTED. Log entries:\n',
+    c.log_handler.printMessages()
     print "Unexpected error:", sys.exc_info()
     try:
         c.disconnect_all()
@@ -39,34 +40,34 @@ if __name__ == '__main__':
         help='''Set the delay rate.  Unitless; eg. seconds per second. Defaults to zero.''')
     p.add_option('-t', '--ld_time', dest='ld_time', type='float', default=-1,
         help='''Load time in seconds since the unix epoch. NOTE: SYSTEM TIME MUST BE ACCURATE! If not specified, load ASAP.''')
+    p.add_option('-v', '--verbose', dest = 'verbose', action = 'store_true', 
+        help = 'Be verbose about errors.')
 
     opts, args = p.parse_args(sys.argv[1:])
 
     if args==[]:
-        print 'Please specify a configuration file! \nExiting.'
-        exit()
+        config_file=None
+    else:
+        config_file=args[0]
+    verbose=opts.verbose
 
-lh=corr.log_handlers.DebugLogHandler()
-
-try:
+try:    
     print 'Connecting...',
-    c=corr.corr_functions.Correlator(args[0],lh)
-    for logger in c.floggers: logger.setLevel(logging.INFO)
-    print 'done.'
+    c=corr.corr_functions.Correlator(config_file=config_file,log_level=logging.DEBUG if verbose else logging.INFO, connect=False)
+    c.connect()
+    print 'done'
 
-    ant,pol=(int(opts.ant_str[:-1]),opts.ant_str[-1])
-    if ant < 0 or ant > c.config['n_ants']:
-        raise RuntimeError("Antenna index out of range (0-%i).")
-    if not pol in c.config['pol_map']:
-        raise RuntimeError("Bad polarisation specified.") 
+    ant_str=opts.ant_str
+    if not ant_str in c.config._get_ant_mapping_list():
+        raise RuntimeError("Bad input specified.") 
 
     if opts.ld_time <0: trig_time = time.time()+0.1
     else: trig_time = opts.ld_time
 
-    print "Setting input %i%c's delay to %es + %es/s with a fringe of %e + %eHz at %s local (%s UTC).... "%(
-        ant,pol,opts.delay,opts.delay_rate,opts.fringe_offset,opts.fringe_rate,
+    print "Setting input %s's delay to %es + %es/s with a fringe of %e + %eHz at %s local (%s UTC).... "%(
+        ant_str,opts.delay,opts.delay_rate,opts.fringe_offset,opts.fringe_rate,
         time.strftime('%H:%M:%S',time.localtime(trig_time)),time.strftime('%H:%M:%S',time.gmtime(trig_time))),
-    act=c.fr_delay_set(ant=ant,pol=pol,
+    act=c.fr_delay_set(ant_str=ant_str,
             delay=opts.delay,
             delay_rate=opts.delay_rate, 
             fringe_phase=opts.fringe_offset,
