@@ -61,30 +61,32 @@ if __name__ == '__main__':
         help='Skip configuration of the equaliser in the F engines.  Default: set the EQ according to config file.')
     p.add_option('-c', '--skip_core_init', dest='prog_10gbe_cores',action='store_false', default=True, 
         help='Skip configuring the 10GbE cores (ie starting tgtap drivers).  Default: start all drivers')
-    p.add_option('-o', '--skip_output_config', dest='config_output',action='store_false', default=True, 
-        help='Do not begin outputting packetised data.  Default: start the output.')
+    p.add_option('-o', '--start_output', dest='start_output',action='store_false', default=True, 
+        help='Begin outputting packetised data immediately.  Default: Do not start the output.')
     p.add_option('-k', '--clk_chk', dest='clk_chk',action='store_false', default=True, 
         help='Skip the F engine clock checks.')
     p.add_option('-v', '--verbose', dest='verbose',action='store_true', default=False, 
         help='Be verbose about errors.')
     p.add_option('-s', '--spead', dest='spead',action='store_false', default=True, 
         help='Do not send SPEAD metadata and data descriptor packets. Default: send all SPEAD info.')
+    p.add_option('', '--prog_timeout', dest = 'prog_timeout_s', type = 'int', default = 2, 
+        help='Timeout between deprogramming devices and reprogramming them. In seconds. Default: 2.')
 
     opts, args = p.parse_args(sys.argv[1:])
 
     check_clocks = opts.clk_chk
-    prog_fpga=opts.prog_fpga
+    prog_fpga = opts.prog_fpga
 
-    if args==[]:
-        config_file=None
+    if args == []:
+        config_file = None
     else:
-        config_file=args[0]
-    verbose=opts.verbose
+        config_file = args[0]
+    verbose = opts.verbose
 
-lh=corr.log_handlers.DebugLogHandler(100)
+lh = corr.log_handlers.DebugLogHandler(100)
 try:
     print 'Connecting...',
-    c=corr.corr_functions.Correlator(config_file=config_file,log_level=logging.DEBUG if verbose else logging.INFO,connect=False,log_handler=lh)
+    c = corr.corr_functions.Correlator(config_file = config_file, log_level = logging.DEBUG if verbose else logging.INFO, connect = False, log_handler = lh)
     c.connect()
     print 'done'
 
@@ -96,15 +98,19 @@ try:
         print ''' Clearing the FPGAs...''',
         sys.stdout.flush()
         c.deprog_all()
-        time.sleep(1)
+        time.sleep(opts.prog_timeout_s)
         print 'done.'
 
         # PROGRAM THE DEVICES
-        print ''' Programming the Fengines with %s and the Xengines with %s...'''%(c.config['bitstream_f'],c.config['bitstream_x']),
+        print ''' Programming the F engines with %s and the X engines with %s...''' % (c.config['bitstream_f'], c.config['bitstream_x']),
         sys.stdout.flush()
         c.prog_all()
         print 'done.'
-    else: print ' Skipped programming FPGAs.'
+    else:
+        print ' Skipped programming FPGAs.'
+
+    # pause
+    time.sleep(2)
 
     if c.tx_status_get():
         print ' Stopping transmission of data...',
@@ -113,26 +119,20 @@ try:
 
     # Disable 10GbE cores until the network's been setup and ARP tables have settled. 
     # Need to do a reset here too to flush buffers in the core. But must be careful; resets are asynchronous and there must be no activity on the core (fifos) when they are reset.
-    #DO NOT RESET THE 10GBE CORES SYNCHRONOUSLY... Packets will be routed strangely!
+    # DO NOT RESET THE 10GBE CORES SYNCHRONOUSLY... Packets will be routed strangely!
     print('\n Pausing 10GbE data exchange...'),
     sys.stdout.flush()
     if c.config['feng_out_type'] == '10gbe':
         print "Pausing Fengs...",
-        c.feng_ctrl_set_all(gbe_enable=False, gbe_rst=False)
-        c.feng_ctrl_set_all(gbe_enable=False, gbe_rst=True)
-        c.syslogger.info("Holding F engine 10GbE cores in reset.")
-
+        c.gbe_reset_hold_f()
     print "Pausing Xengs...",
-    c.xeng_ctrl_set_all(gbe_enable=False, gbe_rst=False)
-    c.xeng_ctrl_set_all(gbe_enable=False, gbe_rst=True)
-    c.syslogger.info("Holding X engine 10GbE cores in reset.")
+    c.gbe_reset_hold_x()
     print 'done.'
 
-
-    print ''' Syncing the F engines...''',
+    print ' Syncing the F engines, this may take a few seconds...'
     sys.stdout.flush()
-    trig_time=c.arm()
-    print 'Armed. Expect trigg at %s local (%s UTC).'%(time.strftime('%H:%M:%S',time.localtime(trig_time)),time.strftime('%H:%M:%S',time.gmtime(trig_time))),
+    trig_time = c.arm()
+    print ' Armed. Expect trigg at %s local (%s UTC).' % (time.strftime('%H:%M:%S', time.localtime(trig_time)), time.strftime('%H:%M:%S', time.gmtime(trig_time))),
     print 'SPEAD packet sent.'
 
     print(''' Checking F engine clocks...'''),
@@ -142,7 +142,8 @@ try:
         else: 
             print ('FAILURES detected!')
             raise RuntimeError("System doesn't work with broken clocks!")
-    else: print 'skipped.'
+    else:
+        print 'skipped.'
 
     print(''' Setting the board indices...'''),
     sys.stdout.flush()
@@ -156,7 +157,7 @@ try:
         c.rf_gain_set_all()
         print ('''done''')
 
-    print(''' Setting the FFT shift schedule to 0x%X...'''%c.config['fft_shift']),
+    print(''' Setting the FFT shift schedule...'''),
     sys.stdout.flush()
     c.fft_shift_set_all()
     print ('''done''')
@@ -168,7 +169,6 @@ try:
         print 'done'
     else: print 'skipped.'
 
-
     # Configure the 10 GbE cores and load tgtap drivers
     print(''' Configuring the 10GbE cores...'''),
     sys.stdout.flush()
@@ -191,11 +191,9 @@ try:
     print(' Starting 10GbE data exchange...'),
     sys.stdout.flush()
     if c.config['feng_out_type'] == '10gbe':
-        c.feng_ctrl_set_all(gbe_enable=False, gbe_rst=False)
-        c.feng_ctrl_set_all(gbe_enable=True, gbe_rst=False)
+        c.gbe_reset_release_f()
         print 'F engines re-enabled.',
-    c.xeng_ctrl_set_all(gbe_enable=False,gbe_rst=False)
-    c.xeng_ctrl_set_all(gbe_enable=True,gbe_rst=False)
+    c.gbe_reset_release_x()
     print 'X engines re-enabled.'
     
     if c.config['feng_out_type'] == 'xaui':
@@ -211,14 +209,14 @@ try:
     print '=================================='
 
     wait_time=len(c.xfpgas)/2
-    print(''' Wait %i seconds for system to stabalise...'''%wait_time),
+    print(''' Wait %i seconds for system to stabilise...'''%wait_time),
     sys.stdout.flush()
     time.sleep(wait_time)
     print '''done'''
 
     print(''' Resetting error counters...'''),
     sys.stdout.flush()
-    c.rst_cnt()
+    c.rst_status_and_count()
     print '''done'''
 
     time.sleep(1)
@@ -238,7 +236,6 @@ try:
             print "Check your 1PPS, clock source, XAUI links, clock on this computer (should be NTP sync'd for reliable arming) and KATCP network links."
             exit_fail()
 
-
     print(''' Checking that FPGAs are sending 10GbE packets...'''),
     sys.stdout.flush()
     if c.check_10gbe_tx(): print 'ok'
@@ -269,25 +266,25 @@ try:
             print ('FAILURES detected!')
             exit_fail()
 
-
     print ''' Checking that all X engines are receiving all their packets...''',
     sys.stdout.flush()
-    time.sleep(1)
-    c.rst_cnt()
+    c.rst_status_and_count()
+    time.sleep(2)
     if c.check_x_miss(): print 'ok'
     else: raise RuntimeError('FAILURES detected!')
 
-    print (''' Setting the number of accumulations to %i (%5.3f seconds) and syncing VACCs...'''%(c.config['n_accs'],c.config['int_time'])),
+    print (''' Setting the number of accumulations to %i (%5.3f seconds) and syncing VACCs...'''%(c.config['n_accs'], c.config['int_time'])),
     sys.stdout.flush()
     c.acc_time_set()
-    c.rst_cnt()
+    c.rst_status_and_count()
     print 'done'
 
     print(''' Checking vector accumulators...'''),
     sys.stdout.flush()
-    print "Waiting for an integration to finish...",
+    sleeptime = c.config['int_time'] + 0.1
+    print "Waiting for an integration to finish (%5.3fs)..." % sleeptime,
     sys.stdout.flush()
-    time.sleep(c.config['int_time']+0.1)
+    time.sleep(sleeptime)
     print('''done. Checking...'''),
     sys.stdout.flush()
     if c.check_vacc(): print 'ok'
@@ -302,21 +299,21 @@ try:
 
     print ' Configuring output to %s:%i...'%(c.config['rx_udp_ip_str'],c.config['rx_udp_port']),
     sys.stdout.flush()
-    if opts.config_output and (c.config['out_type'] == '10gbe'): 
+    if (c.config['out_type'] == '10gbe'): 
         c.config_udp_output()
         print 'done'
     else: print 'skipped.'
 
-    print ' Starting transmission of data...',
-    sys.stdout.flush()
-    if opts.config_output: 
+    if opts.start_output: 
+        print ' Starting transmission of data...',
+        sys.stdout.flush()
         c.tx_start()
         print 'done'
     else: print 'skipped.'
 
     print(''' Resetting error counters...'''),
     sys.stdout.flush()
-    c.rst_cnt()
+    c.rst_status_and_count()
     print '''done'''
 
     print(''' Enabling KITT...'''),
