@@ -28,7 +28,19 @@ class DeviceExampleServer(katcp.DeviceServer):
         super(DeviceExampleServer, self).__init__(*args, **kwargs)
         self.c = None
 
-    @request(Str(default='/etc/corr/config'), Int(default=100))
+    @request(Int(default=-1))
+    @return_reply(Int(), Int(), Int())
+    def request_nb_set_cf(self, sock, freq):
+        """Sets the center frequency for narrowband."""
+        if self.c is None:
+            return ("fail","... you haven't connected yet!")
+        try:
+            rva, rvb, rvc = corr.corr_nb.channel_select(self.c, freq)
+            return ("ok", rva, rvb, rvc)
+        except:
+            return ("fail", "Something broke spectacularly. Check the log.")
+
+    @request(Str(default='/etc/corr/default'), Int(default=100))
     @return_reply()
     def request_connect(self, sock, config_file, log_len):
         """Connect to all the ROACH boards. Please specify the config file and the log length. Clears any existing log. Call this again if you make external changes to the config file to reload it."""
@@ -104,24 +116,32 @@ class DeviceExampleServer(katcp.DeviceServer):
         else:
             #return("fail","it broke.")
             return("fail","Sorry, your input number is invalid. Valid range: 0 to %i."%(self.c.config['n_inputs']-1))
-            
+           
 
-    @request()
     @return_reply(Str(),Str())
-    def request_tx_start(self, sock):
-        """Start transmission to the IP address given in the config file."""
+    def request_tx_start(self, sock, orgmsg):
+        """Start transmission to the given IP address and port, or use the defaults from the config file if not specified. The first argument should be the IP address in dotted-quad notation. The second is the port."""
         if self.c is None:
             return ("fail","... you haven't connected yet!")
         try:
+            if len(orgmsg.arguments)>1:
+                dest_port=int(orgmsg.arguments[1])
+            else:
+                dest_port=None
+            if len(orgmsg.arguments)>1:
+                dest_ip_str=orgmsg.arguments[0]
+            else:
+                dest_ip_str=None
+            self.c.config_udp_output(dest_ip_str=dest_ip_str,dest_port=dest_port)
             self.c.spead_issue_all()
             self.c.tx_start()
             return ("ok",
             "data %s:%i"%(self.c.config['rx_udp_ip_str'],self.c.config['rx_udp_port']),
             "meta %s:%i"%(self.c.config['rx_meta_ip_str'],self.c.config['rx_udp_port'])
-            )
+            )   
         except:
             return ("fail","Something broke. Check the log.")
-            
+      
     @request()
     @return_reply(Str())
     def request_spead_issue(self, sock):
@@ -190,7 +210,7 @@ class DeviceExampleServer(katcp.DeviceServer):
 
     def request_get_adc_snapshots(self, sock, orgmsg):
         """Grabs a snapshot of data from the specified antennas. 
-            \n@Param boolean Sync to 1PPS (ie align all snapshots). Note that this could cost a bit of time as we wait for the next 1PPS. 
+            \n@Param integer Sync to 1PPS (ie align all snapshots). Note that this could cost a bit of time as we wait for the next 1PPS. 
             \n@Param integer Wait for ADC level of trigger_level to capture transients.
             \n@Params list of antenna strings.
             \n@reply str antenna name.
@@ -202,7 +222,7 @@ class DeviceExampleServer(katcp.DeviceServer):
         if len(orgmsg.arguments)<3: 
             return katcp.Message.reply(orgmsg.name,"fail","... you didn't specify enough arguments.")
         try:
-            sync_to_pps=bool(orgmsg.arguments[0])
+            sync_to_pps=bool(int(orgmsg.arguments[0]))
             trig_level=int(orgmsg.arguments[1])
             ant_strs=orgmsg.arguments[2:]
             for ant_str in ant_strs:
@@ -210,7 +230,7 @@ class DeviceExampleServer(katcp.DeviceServer):
                     return katcp.Message.reply(orgmsg.name,"fail","Antenna not found. Valid entries are %s."%str(self.c.config._get_ant_mapping_list()))
             snap_data=self.c.get_adc_snapshots(ant_strs,trig_level=trig_level,sync_to_pps=sync_to_pps)
             for ant_str,data in snap_data.iteritems():
-                self.reply_inform(sock,katcp.Message.inform(orgmsg.name,ant_str,str(data['timestamp']),str(data['offset']),*data['data']),orgmsg)
+                self.reply_inform(sock,katcp.Message.inform(orgmsg.name,ant_str,str(data['timestamp']*1000),str(data['offset']),*data['data']),orgmsg)
             return katcp.Message.reply(orgmsg.name,'ok',str(len(snap_data)))
         except:
             return katcp.Message.reply(orgmsg.name,"fail","something broke. sorry.")
@@ -291,7 +311,7 @@ class DeviceExampleServer(katcp.DeviceServer):
         if self.c is None:
             return ("fail","... you haven't connected yet!")
         fstat = self.c.feng_status_get_all()
-        self.c.rst_fstat()
+        self.c.rst_fstatus()
         for i in fstat:
             out_str=[]
             for ent in fstat[i]: 
