@@ -50,7 +50,7 @@ try:
 
     print('\nResetting error counters...'),
     sys.stdout.flush()
-    c.rst_cnt()
+    c.rst_status_and_count()
     print 'done.'
 
 except KeyboardInterrupt:
