@@ -25,10 +25,8 @@ import corr, time, numpy, struct, sys, logging, pylab, matplotlib
 polList = []
 report = []
 
-
 def exit_fail():
-    print 'FAILURE DETECTED. Log entries:\n', 
-    c.log_handler.printMessages()
+    print 'FAILURE DETECTED. Log entries:\n', lh.printMessages() 
     print "Unexpected error:", sys.exc_info()
     try:
         c.disconnect_all()
@@ -64,10 +62,10 @@ def parseAntenna(antArg):
 def get_data(pol):
     print 'Integrating data %i from %s:' % (pol['num_accs'], pol['ant_str'])
     print ' Grabbing data off snap blocks...',
-    unpacked_vals=c.get_quant_snapshot(pol['ant_str'],n_spectra=8)
+    unpacked_vals = c.get_quant_snapshot(pol['ant_str'], n_spectra = 8)
     print 'done.'
     print ' Accumulating...', 
-    pol['accumulations']=numpy.sum([pol['accumulations'],numpy.sum(numpy.abs(unpacked_vals),axis=0)],axis=0)
+    pol['accumulations'] = numpy.sum([pol['accumulations'],numpy.sum(numpy.abs(unpacked_vals),axis=0)],axis=0)
     pol['num_accs'] += 8
     print 'done.'
     return
@@ -89,11 +87,6 @@ if __name__ == '__main__':
 
     if opts.man_trigger: man_trigger = True
     else: man_trigger = False
-    if opts.ant != None:
-        ant_strs = parseAntenna(opts.ant)
-    else:
-        print 'No antenna given for which to plot data.'
-        exit_fail()
 
     if args==[]:
         config_file=None
@@ -101,9 +94,16 @@ if __name__ == '__main__':
         config_file=args[0]
     verbose=opts.verbose
 
+lh = corr.log_handlers.DebugLogHandler(35)
+if opts.ant != None:
+    ant_strs = parseAntenna(opts.ant)
+else:
+    print 'No antenna given for which to plot data.'
+    exit_fail()
+
 try:
     print 'Connecting...',
-    c=corr.corr_functions.Correlator(config_file=config_file,log_level=logging.DEBUG if verbose else logging.INFO,connect=False)
+    c = corr.corr_functions.Correlator(config_file = config_file, log_level = logging.DEBUG if verbose else logging.INFO, connect = False)
     c.connect()
     print 'done'
 
@@ -122,7 +122,7 @@ try:
     fig = matplotlib.pyplot.figure()
     for p, ant_str in enumerate(ant_strs):
         if not ant_str in c.config._get_ant_mapping_list():
-            print 'Unrecognised input %s. Must be in ' %(pol),c.config._get_ant_mapping_list()
+            print 'Unrecognised input %s. Must be in ' % p, c.config._get_ant_mapping_list()
             exit_clean()
         polList.append({'ant_str':ant_str})
         polList[p]['accumulations'] = numpy.zeros(c.config['n_chans'])
