@@ -13,12 +13,13 @@ Revisions:\n
 '''
 import corr, time, numpy, pylab, struct, sys, logging
 
-#brams
-brams=['bram']
 dev_name = 'snap_xeng0'
 
+report=[]
+
 def exit_fail():
-    print 'FAILURE DETECTED. Log entries:\n',lh.printMessages()
+    print 'FAILURE DETECTED. Log entries:\n',
+    c.log_handler.printMessages()
     print "Unexpected error:", sys.exc_info()
     try:
         c.disconnect_all()
@@ -43,17 +44,16 @@ if __name__ == '__main__':
     opts, args = p.parse_args(sys.argv[1:])
 
     if args==[]:
-        print 'Please specify a configuration file! \nExiting.'
-        exit()
-
-report=[]
-lh=corr.log_handlers.DebugLogHandler()
+        config_file=None
+    else:
+        config_file=args[0]
+    verbose=opts.verbose
 
 try:
-    print 'Parsing configuration file...',
-    c=corr.corr_functions.Correlator(args[0],lh)
-    for s,server in enumerate(c.xsrvs): c.loggers[s].setLevel(10)
-    print 'done.'
+    print 'Connecting...',
+    c=corr.corr_functions.Correlator(config_file=config_file,log_level=logging.DEBUG if verbose else logging.INFO,connect=False)
+    c.connect()
+    print 'done'
 
     binary_point = c.config['feng_fix_pnt_pos']
     packet_len=c.config['10gbe_pkt_len']
@@ -64,7 +64,6 @@ try:
     adc_levels_acc_len = c.config['adc_levels_acc_len']
     x_per_fpga = c.config['x_per_fpga']
     n_ants = c.config['n_ants']
-    n_stokes = c.config['n_stokes']
     xeng_acc_len = c.config['xeng_acc_len']
     n_bls = c.config['n_bls']
 
@@ -79,14 +78,14 @@ try:
         exit_fail()
 
     if c.config['xeng_format'] == 'inter':
-        offset = ch_offset * n_stokes * n_bls * 2   #hardcoded for demux of 8
+        offset = ch_offset * n_bls * 2   #hardcoded for demux of 8
     else:
-        offset = (ch_offset)%(n_chans_per_x) * n_stokes * n_bls * 2   #hardcoded for demux of 8
+        offset = (ch_offset)%(n_chans_per_x) * n_bls * 2   #hardcoded for demux of 8
 
     print '------------------------'
     print 'Triggering capture at word offset %i...'%offset,
     sys.stdout.flush()
-    bram_dmp=c.xsnap_all(dev_name, brams, man_trig = False, wait_period = 2, offset = offset)
+    bram_dmp=corr.snap.snapshots_get(c.xfpgas,dev_name, man_trig = False, wait_period = 2, offset = offset)
     print 'done.'
 
     print 'Unpacking bram contents...'
@@ -111,17 +110,16 @@ try:
         for li in range(len(bram_data[xeng]) / 2):
             #index over complex numbers in bram
             index = li + bram_dmp['offsets'][xeng] / 2
-            stokes = index % n_stokes
-            bls_index = (index / n_stokes) % n_bls
+            bls_index = index  % n_bls
             if c.config['xeng_format'] == 'inter':
-                freq = (index / n_stokes / n_bls) * x_per_fpga * len(c.xfpgas) + xeng
+                freq = (index / n_bls) * x_per_fpga * len(c.xfpgas) + xeng
             else:
-                freq = (index / n_stokes / n_bls) + x_per_fpga * xeng * c.config['n_chans']/c.config['n_xeng']
+                freq = (index / n_bls) + x_per_fpga * xeng * c.config['n_chans']/c.config['n_xeng']
             i, j = c.get_bl_order()[bls_index]
             real_val = bram_data[xeng][li * 2]
             imag_val = bram_data[xeng][li * 2 + 1]
             if (real_val != 0) or (imag_val != 0) or opts.verbose:
-                print '[%s] [%4i]: Freq: %i. bls: %2i_%2i. Stokes: %i. Raw value: 0x%05x + 0x%05xj (%6i + %6ij).'%(c.xsrvs[xeng], index, freq, i, j, stokes, real_val, imag_val, real_val, imag_val)
+                print '[%s] [%4i]: Freq: %i. bls: %s_%s. Raw value: 0x%05x + 0x%05xj (%6i + %6ij).'%(c.xsrvs[xeng], index, freq, i, j, real_val, imag_val, real_val, imag_val)
         print 'Done with %s, X-engine %i.'%(c.xsrvs[xeng],xeng)
     print 'Done with all.'
 
